@@ -29,6 +29,7 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glade/glade.h>
 
+#include "async-pixbuf-ops.h"
 #include "gthumb-window.h"
 #include "pixbuf-utils.h"
 
@@ -69,20 +70,39 @@ destroy_cb (GtkWidget  *widget,
 }
 
 
+static gboolean
+preview_done_cb (GthPixbufOp *pixop,
+		 gboolean     completed,
+		 DialogData  *data)
+{
+	gtk_widget_queue_draw (data->p_preview_image);
+	g_object_unref (pixop);
+	return FALSE;
+}
+
+
 static void
 apply_changes (DialogData *data, 
 	       GdkPixbuf  *src, 
 	       GdkPixbuf  *dest, 
 	       gboolean    preview)
 {
-	int        levels;
+	int          levels;
+	GthPixbufOp *pixop;
 	
 	levels = (int) gtk_range_get_value (GTK_RANGE (data->p_levels_hscale));
-	_gdk_pixbuf_posterize (src, dest, levels);
+	pixop = _gdk_pixbuf_posterize (src, dest, levels);
 
-	if (preview)
-		gtk_image_set_from_pixbuf (GTK_IMAGE (data->p_preview_image),
-					   dest);
+	if (preview) {
+		g_signal_connect (G_OBJECT (pixop),
+				  "done",
+				  G_CALLBACK (preview_done_cb),
+				  data);
+		gth_pixbuf_op_start (pixop);
+	} else {
+		window_exec_pixbuf_op (data->window, pixop);
+		g_object_unref (pixop);
+	}
 }
 
 
@@ -103,8 +123,10 @@ static void
 cancel_cb (GtkWidget  *widget, 
 	   DialogData *data)
 {
-	if (data->modified)
+	if (data->modified) {
 		image_viewer_set_pixbuf (data->viewer, data->image);
+		window_image_modified (data->window, FALSE);
+	}
 	gtk_widget_destroy (data->dialog);
 }
 
@@ -118,7 +140,6 @@ preview_cb (GtkWidget  *widget,
 
 	preview = gdk_pixbuf_copy (data->image);
 	apply_changes (data, preview, preview, FALSE);
-	image_viewer_set_pixbuf (data->viewer, preview);
 	g_object_unref (preview);
 
 	data->modified = TRUE;
